import { useEffect, useState } from 'react';
import { Highlight, themes } from 'prism-react-renderer';

import * as style from './text.css';

export default function Text({ language, text }: { language: string, text: string }) {
	console.log(language);
	const lines = text.split('\n');

	const media_matcher = window.matchMedia('(prefers-color-scheme: light)');
	const [light_theme, set_light_theme] = useState(media_matcher.matches);

	function check_light_theme(event) {
		if (light_theme != event.matches) {
			set_light_theme(!light_theme);
		}
	}

	useEffect(() => {
		media_matcher.addEventListener('change', check_light_theme);
		return () => {
			media_matcher.removeEventListener('change', check_light_theme);
		};
	});

	return <div className={style.group}>
		<p className={style.line_numbers}>{lines.map((_, index) => `${index}\n`)}</p>
		<Highlight
			theme={themes[light_theme ? 'nightOwlLight' : 'oneDark']}
			code={text}
			language={language}
		>
			{({ className, style, tokens, getLineProps, getTokenProps }) => (
				<div>
					{tokens.map((line, i) => (
						<div key={i} {...getLineProps({ line })}>
							{line.map((token, key) => (
								<span key={key} {...getTokenProps({ token })} />
							))}
						</div>
					))}
				</div>
			)}
		</Highlight>
	</div>;
}
